@@ -173,7 +173,7 @@ class GitLabApi(object):
             response = requests.get(url, headers=self.generate_v4_request_header(token), verify=self.ssl_verify, params=self.get_params(
                 params, PER_PAGE, current_page, keyset, last_id))
             headers = response.headers
-            if headers.get('x-per-page', None):
+            if headers.get('x-per-page'):
                 if data := safe_json_response(response):
                     # The system key denotes anything autogenerated by GitLab.
                     # If we include this key in our counts, it will lead to inaccurate note counts
@@ -182,8 +182,7 @@ class GitLabApi(object):
                         self.log.info(
                             f"Retrieved {PER_PAGE * (current_page - 1) + x_per_page} {api}")
                         if keyset:
-                            last_id = self.get_last_id(
-                                headers.get("Link", None))
+                            last_id = self.get_last_id(headers.get("Link"))
                             if last_id is None:
                                 break
                         if not headers.get("x-next-page"):
@@ -197,6 +196,9 @@ class GitLabApi(object):
                             count += len(adata)
                             break
                         count += len(adata)
+                # If response is empty
+                else:
+                    break
             else:
                 if data := safe_json_response(self.generate_get_request(host, token, api, params=self.get_params(
                         params, PER_PAGE, current_page, keyset, last_id))):
