@@ -1,7 +1,9 @@
-from base64 import b64decode, b64encode
 import getpass
 import sys
+import os
+
 from re import sub
+from base64 import b64decode, b64encode
 
 
 def strip_numbers(s):
@@ -49,4 +51,4 @@ def deobfuscate(secret):
         return b64decode(secret.encode("ascii")).decode("ascii")
     except Exception as e:
         print(f"Invalid token - {e}")
-        sys.exit()
+        sys.exit(os.EX_CONFIG)
